package msgpack.rpcx

import msgpack.rpcx.interface.AuthInterface

import org.msgpack.rpc.loop.EventLoop

/** RPC Client
 *
 * @param host of server
 * @param port of server
 *
 * @author myst3r10n
 */
class Client(host: String, port: Int) extends Proxy {

  /** RPC loop. */
  protected var loop = EventLoop.start

  /** RPC client. */
  protected var client = new org.msgpack.rpc.Client(host, port, loop)

  /** proxy to [[msgpack.rpcx.AuthInterface]]. */
  protected val proxy = client.proxy(classOf[AuthInterface])

  /** Waits till client released. */
  def await {

    loop.join

  }

  /** Release all busy resources. */
  def release {

    loop.shutdown
    client.close

  }

  /** Get current request timeout in seconds. */
  def requestTimeout = client.getRequestTimeout

  /** Set current request timeout in seconds.
   *
   * @param timeout for request
   */
  def requestTimeout_=(timeout: Int) {

    client.setRequestTimeout(timeout)

  }
}

