package msgpack.rpcx

import msgpack.rpcx.interface.AuthInterface

/** Proxy to [[msgpack.rpcx.AuthInterface]].
 *
 * @author myst3r10n
 */
trait Proxy {

  /** unique client authentication id. */
  protected var authId = ""

  /** Proxy to authentication interface. */
  protected val proxy: AuthInterface

  /** Sends heartbeat to RPC server. */
  def heartbeat {

    proxy.heartbeat(authId)

  }

  /** Login into RPC server.
   *
   * @param username of client
   * @param password of client
   */
  def login(username: String, password: String) {

    authId = proxy.login(username, password)

  }

  /** Logout from RPC server. */
  def logout {

    proxy.logout(authId)

  }
}

